@@ -24,7 +24,7 @@ class LocalRepo(Recycle, _SharedAPI):
 
     enabled = True
     private = False
-    installable = True
+    installable = True  # Might not need this, generalmainframe can be installable, just not on pypi
     name = ...
     version = "0.0.1"  # type: Ver
     description = "Missing description."
@@ -36,8 +36,14 @@ class LocalRepo(Recycle, _SharedAPI):
     metadata_keys = [key for key, value in locals().items() if not key.startswith("_")]
     _recycle_keys = {"name": lambda name: str(LocalRepo.get_path_from_name(name=name))}
 
-    def __init__(self, name=None):
-        self.path = self.get_path_from_name(name=name)
+    def __init__(self, name=None, path=None):
+        if path is None:
+            self.path = self.get_path_from_name(name=name)
+        else:
+            path = Path(path)
+            if not path.endswith(name):
+                path /= name
+            self.path = path
         self.has_loaded_metadata = False
 
     def __repr__(self):
@@ -152,6 +158,7 @@ class LocalRepo(Recycle, _SharedAPI):
     def get_test_template_path(self):       return self.get_test_path() / f"test_{self.name}.py"
     def get_init_path(self):                return self.path / self.name / "__init__.py"
     def get_randomtesting_path(self):       return self.path / "randomtesting.py"
+    def get_generate_path(self):            return self.path / "generate.py"
 
     @deco_cache()
     def get_test_paths(self):
@@ -205,8 +212,8 @@ class LocalRepo(Recycle, _SharedAPI):
     def upload(self):
         """ Upload local repo to PyPI.
             Todo: Make sure twine is installed when trying to upload to pypi. """
-        # if self.private:
-        #     raise AttributeError("Cannot upload private repo.")
+        if self.private:
+            raise AttributeError("Cannot upload private repo.")
 
         self.create_sdist()
         with self.path.as_working_dir():
