@@ -7,6 +7,10 @@ import unittest
 
 
 class TestPackager(unittest.TestCase):
+    """ Skipped:
+        spawn_children
+        spawn_parents
+        """
     def test_exists(self):
         self.assertEqual(True, Packager().exists())
 
